User Guide
==========

This tutorial is in several stages that cover all of the basic and more of the advanced functionality that
Ganga provides. To follow it properly, you should go through each stage in turn. Please post an issue if
you encounter any problems!

.. toctree::
    InstallAndBasicUsage
    Configuration
    JobManipulation
    RunningExecutables
    UsingDifferentBackends
    InputAndOutputData
    Splitters
    PostProcessors
    MiscellaneousFunctionality
    Queues
    Tasks
    PurePythonUsage
    GangaService
    DevelopingNewApplication


Sections still to be added:

* Pure Python Usage
* Ganga as a Service
* Developing a New Application